@@ -1,23 +1,24 @@
 #' Convert every date method we know about to POSIXlt and POSIXct
 #' @name DateCoercion
 #' @keywords internal 
-#' @aliases as.POSIXlt.fts as.POSIXlt.its as.POSIXlt.timeSeries as.POSIXlt.irts as.POSIXlt.xts as.POSIXlt.zoo as.POSIXlt.tis as.POSIXct.fts as.POSIXct.its as.POSIXct.timeSeries as.POSIXct.irts as.POSIXct.xts as.POSIXct.zoo as.POSIXct.tis
-#' @method as.POSIXlt fts
-#' @method as.POSIXlt its
-#' @method as.POSIXlt timeSeries
-#' @method as.POSIXlt irts
-#' @method as.POSIXlt xts
-#' @method as.POSIXlt zoo
-#' @method as.POSIXlt tis
-#' @method as.POSIXct fts
-#' @method as.POSIXct its
-#' @method as.POSIXct timeSeries
-#' @method as.POSIXct irts
-#' @method as.POSIXct xts
-#' @method as.POSIXct zoo
-#' @method as.POSIXct tis
-as.POSIXlt.fts <- function(x, tz = "", ...) as.POSIXlt(fts::dates.fts(x))
+#'
+#' @S3method as.POSIXlt fts
+#' @S3method as.POSIXlt its
+#' @S3method as.POSIXlt timeSeries
+#' @S3method as.POSIXlt irts
+#' @S3method as.POSIXlt xts
+#' @S3method as.POSIXlt zoo
+#' @S3method as.POSIXlt tis
+#' @S3method as.POSIXct fts
+#' @S3method as.POSIXct its
+#' @S3method as.POSIXct timeSeries
+#' @S3method as.POSIXct irts
+#' @S3method as.POSIXct xts
+#' @S3method as.POSIXct zoo
+NULL
+
 as.POSIXct.fts <- function(x, tz = "", ...) as.POSIXct(fts::dates.fts(x))
+as.POSIXlt.fts <- function(x, tz = "", ...) as.POSIXlt(fts::dates.fts(x))
 
 as.POSIXlt.its <- function(x, tz = "", ...) as.POSIXlt(attr(x, "dates"))
 as.POSIXct.its <- function(x, tz = "", ...) as.POSIXct(attr(x, "dates"))
@@ -43,7 +44,15 @@ as.POSIXlt.tis <- function(x, tz = "", ...) as.Date(x)
 
 #' Convenience method to reclass dates post-modification.
 #' @keywords internal
-#' @aliases reclass_date reclass_date.POSIXlt reclass_date.POSIXct reclass_date.chron reclass_date.timeDate reclass_date.its reclass_date.ti reclass_date.Date
+#'
+#' @export reclass_date
+#' @S3method reclass_date POSIXlt
+#' @S3method reclass_date POSIXct
+#' @S3method reclass_date chron
+#' @S3method reclass_date timeDate
+#' @S3method reclass_date its
+#' @S3method reclass_date ti
+#' @S3method reclass_date Date
 reclass_date <- function(new, orig) UseMethod("reclass_date", orig)
 reclass_date.POSIXlt <- function(new, orig) {
   as.POSIXlt(new)
